Management — Django Kaos Utils documentation

# Management

class dj_kaos_utils.management.TaskCommand(stdout=None, stderr=None, no_color=False, force_color=False)

  Bases: `BaseCommand`

  An abstraction over `django.core.management.BaseCommand` to run tasks from the django manage.py cli services

  print_success_message(return_val)

    Override this method to change the success message being printed. You have access

    Parameters

      return_val – return value from `run_task()`

  run_task(*args, **options)

    Override this method to run your task. You have access to options and args

    Returns

      A meaningful summary of the task run. E.g. number of rows updated.